translate.misc.progressbar.DotsProgressBar

Package translate :: Package misc :: Module progressbar :: Class DotsProgressBar |
[hide private]
[frames] | no frames]

# Class DotsProgressBar

source code

An ultra-simple progress indicator that just writes a dot for each action

Instance Methods | [hide private]
__init__(self) | source code
show(self, verbosemessage) show a dot for progress :-) | source code
close(self) | source code
__del__(self) | source code